@@ -1,5 +1,7 @@
 from .adversarialae import AdversarialAE
 from .model_distillation import ModelDistillation
 
-__all__ = ["AdversarialAE",
-           "ModelDistillation"]
+__all__ = [
+    "AdversarialAE",
+    "ModelDistillation"
+]
